@@ -2,11 +2,11 @@ import logging
 
 from yachalk import chalk
 
-from magnus.interaction import (AsIs, Pipeline, Task,
-                                get_experiment_tracker_context,
-                                get_from_catalog, get_parameter, get_run_id,
-                                get_secret, put_in_catalog, step,
-                                store_parameter, track_this)
+from magnus.interaction import (get_experiment_tracker_context,
+                                get_from_catalog, get_object, get_parameter,
+                                get_run_id, get_secret, put_in_catalog,
+                                put_object, store_parameter, track_this)
+from magnus.sdk import AsIs, Pipeline, Task, step
 
 chalk_colors = {
     'debug': chalk.grey,
